==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/modules/tour/messages/fr/profile.php <==
<?php
return array (
  '<strong>Administration (Modules)</strong>' => '<strong>Administration (Modules)</strong>',
  '<strong>Edit</strong> account' => '<strong>Modifier</strong> le compte',
  '<strong>Hurray!</strong> The End.' => '<strong>Hourra !</strong> C\'est fini.',
  '<strong>Hurray!</strong> You\'re done!' => '<strong>Hourra !</strong> Vous avez terminé !',
  '<strong>Profile</strong> menu' => 'Menu du <strong>Profil</strong>',
  '<strong>Profile</strong> photo' => 'Photo de <strong>Profil</strong>',
  '<strong>Profile</strong> stream' => 'Fil d\'activités du <strong>Profil</strong>',
  '<strong>User profile</strong>' => '<strong>Profil utilisateur</strong>',
  'Click on this button to update your profile and account settings. You can also add more information to your profile.' => 'Cliquez sur ce bouton pour mettre à jour votre profil et vos paramètres de compte. Vous pouvez également ajouter plus d\'informations à votre profil.',
  'Each profile has its own pin board. Your posts will also appear on the dashboards of those users who are following you.' => 'Chaque profil possède son propre tableau d\'affichage. Vos messages seront également diffusés sur les tableaux de bord des utilisateurs qui vous suivent.',
  'Just like in the space, the user profile can be personalized with various modules.<br><br>You can see which modules are available for your profile by looking them in “Modules” in the account settings menu.' => 'Tout comme dans l\'espace, le profil de l\'utilisateur peut être personnalisé avec différents modules.<br />Vous pouvez découvrir quels sont les modules disponibles pour votre profil en regardant dans "Modules" dans le menu des paramètres de compte.',
  'This is your public user profile, which can be seen by any registered user.' => 'Ceci est votre profil d\'utilisateur public, qui peut être vu par tout utilisateur enregistré.',
  'Upload a new profile photo by simply clicking here or by drag&drop. Do just the same for updating your cover photo.' => 'Ajouter une photo de profil en cliquant ici ou par glisser-déposer. Faites la même chose pour mettre à jour votre photo de couverture.',
  'You\'ve completed the user profile guide!' => 'Vous avez terminé le guide de profil de l\'utilisateur !',
  'You\'ve completed the user profile guide!<br><br>To carry on with the administration guide, click here:<br /><br />' => 'Vous avez terminé le guide de profil de l\'utilisateur !<br> Pour poursuivre avec le guide d\'administration, cliquez ici :<br /><br />',
);

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/modules/tour/messages/fr/profile.php <==
<?php
return [
  '<strong>Administration (Modules)</strong>' => '<strong>Administration (Modules)</strong>',
  '<strong>Edit</strong> account' => '<strong>Modifier</strong> le compte',
  '<strong>Hurray!</strong> The End.' => '<strong>Hourra !</strong> C\'est fini.',
  '<strong>Hurray!</strong> You\'re done!' => '<strong>Hourra !</strong> Vous avez terminé !',
  '<strong>Profile</strong> menu' => 'Menu du <strong>Profil</strong>',
  '<strong>Profile</strong> photo' => 'Photo de <strong>Profil</strong>',
  '<strong>Profile</strong> stream' => 'Fil d\'activités du <strong>Profil</strong>',
  '<strong>User profile</strong>' => '<strong>Profil utilisateur</strong>',
  'Click on this button to update your profile and account settings. You can also add more information to your profile.' => 'Cliquez sur ce bouton pour mettre à jour votre profil et vos paramètres de compte. Vous pouvez également ajouter plus d\'informations à votre profil.',
  'Each profile has its own pin board. Your posts will also appear on the dashboards of those users who are following you.' => 'Chaque profil possède son propre tableau d\'affichage. Vos messages seront également diffusés sur les tableaux de bord des utilisateurs qui vous suivent.',
  'Just like in the space, the user profile can be personalized with various modules.<br><br>You can see which modules are available for your profile by looking them in "Modules" in the account settings menu.' => 'Tout comme dans l\'espace, le profil utilisateur peut être personnalisé avec différents modules.<br><br>Vous pouvez voir quels modules sont disponibles pour votre profil en les recherchant dans « Modules » dans le menu des paramètres du compte.',
  'This is your public user profile, which can be seen by any registered user.' => 'Ceci est votre profil d\'utilisateur public, qui peut être vu par tout utilisateur enregistré.',
  'Upload a new profile photo by simply clicking here or by drag&drop. Do just the same for updating your cover photo.' => 'Ajouter une photo de profil en cliquant ici ou par glisser-déposer. Faites la même chose pour mettre à jour votre photo de couverture.',
  'You\'ve completed the user profile guide!' => 'Vous avez terminé le guide de profil de l\'utilisateur !',
  'You\'ve completed the user profile guide!<br><br>To carry on with the administration guide, click here:<br /><br />' => 'Vous avez terminé le guide de profil de l\'utilisateur !<br> Pour poursuivre avec le guide d\'administration, cliquez ici :<br /><br />',
];
